import pyvista
from .plot import reset_plotter

__all__ = ["set_interactive"]


def set_interactive(state: bool = True):
    """
    Change settings to switch from interactive to non-interactive plots.

    If `state` is `True`, this runs:

    >>> pyvista.OFF_SCREEN = False
    >>> pyvista4dolfinx.reset_plotter()

    If `state` is `False` (this requires a renderable screen to be configured;
    on Unix systems requiring `libgl1-mesa-dev` and `mesa-utils`), this runs:

    >>> pyvista.OFF_SCREEN = True
    >>> pyvista4dolfinx.reset_plotter()

    Parameters
    ----------
    state : bool, optional
        Whether to activate or deactivate interactive plots, by default True
    """
    if state:
        pyvista.OFF_SCREEN = False
        reset_plotter()
    else:
        pyvista.OFF_SCREEN = True
        reset_plotter()



"""pyvista4dolfinx: A simple plotting interface for DOLFINx using PyVista.

This package provides convenient plotting functions for DOLFINx finite element
computations, with MPI-safe implementations for parallel execution.
"""

from importlib.metadata import version, PackageNotFoundError

try:
    __version__ = version("pyvista4dolfinx")
except PackageNotFoundError:
    # Package is not installed
    __version__ = "unknown"

from .plot import plot, show, screenshot, reset_plotter
from .safeplotter import Plotter
from .misc import *
